//Функция генерации обучающих данных (для динамики выходных характеристик)
function [SystemOutputCharacteristics...//Выходные характеристики
          ]=AdvancedModelLearningDataDynamic(SystemParametrsNames,...//Имена параметров, определяющих динамику
                                             SystemParametrsValues,...//Значения параметров, определяющих динамику
                                             SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                             SystemOutputCharacteristicsNamesIndexes,...//Индексы выходных характеристик системы
                                             SystemOutputCharacteristicsIndexes,...//Индексы выходных характеристик системы (в именах)
                                             SystemShemaName,...//Имя схемы системы
                                             SystemOutputCharacteristicsCompressionFunctions...//Функция сжатия динамики
                                             )
    //Проверяем число аргументов
    if argn(2) ~= 7 then
        error('Function AdvancedModelLearningData takes 7 arguments');
        return;
    end
    
    //Проверяем корректность аргументов
    if (type(SystemShemaName) ~= 10) || (size(SystemShemaName) ~= [1, 1]) then
        error('The 6th argument of function AdvancedModelLearningData is scalar string');
        return;
    end
    
    //Загружаем схему системы
    SystemShema = xcosDiagramToScilab(SystemShemaName);
    
    //Векторизуемая функция вычислительного эксперимента
    function [result]=ComputerExperimentWithCompression(ind)
        //Проводим вычислительный эксперимент
        Dynamics = ComputingExperiment(SystemParametrsNames,...//Имена параметров
                                       SystemParametrsValues(ind,:),...//Значения параметров
                                       SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                       SystemShema...//Схема системы
                                       );
        
        //Сжимаем полученные динамики
        result = CountDynamicsProections(Dynamics,...//Массив динамик
                                         SystemOutputCharacteristicsNamesIndexes,...//Индексы имен динамик
                                         SystemOutputCharacteristicsIndexes,...//Индексы динамик (в именах)
                                         SystemOutputCharacteristicsCompressionFunctions...//Функция фильтра динамики
                                         ); 
    endfunction
    
    //Проводим вычислительные эксперименты и преобразовываем результаты этих экспериментов
    SystemOutputCharacteristics = Vectorization((1:size(SystemParametrsValues)(1))',...
                                                ComputerExperimentWithCompression);
endfunction
