//Функция генерации обучающих данных (для динамики выходных характеристик)
function [SystemOutputCharacteristics,...//Выходные характеристики
          ModelParametrsValues...//Значения параметров модели
          ]=AdvancedModelLearningDataGeneralTimeGrid(ModelParametrsNames,...//Имена параметров модели
                                                     SystemParametrsNames,...//Имена параметров, определяющих динамику
                                                     SystemParametrsValues,...//Значения параметров, определяющих динамику
                                                     SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                                     SystemOutputCharacteristicsNamesIndexes,...//Индексы выходных характеристик системы
                                                     SystemOutputCharacteristicsIndexes,...//Индексы выходных характеристик системы (в именах)
                                                     SystemShemaName,...//Имя схемы системы
                                                     TimeMoments...//Моменты времени
                                                     )
    //Проверяем аргументы
    if argn(2) ~= 8 then
        error('Function AdvancedModelLearningDataGeneralTimeGrid takes 8 arguments');
        return;
    end
    
    //Проверяем корректность аргументов
    isemptyModelParametrsNames = isempty(ModelParametrsNames);
    if ~isemptyModelParametrsNames && (type(ModelParametrsNames) ~= 10) ||...
       (size(ModelParametrsNames)(1) ~= 1) then
        error('The first argument of AdvancedModelLearningDataDynamic function is string matrix 1xM');
        return;
    end
    if (type(SystemShemaName) ~= 10) || (size(SystemShemaName) ~= [1, 1]) then
        error('The 6th argument of function AdvancedModelLearningData is scalar string');
        return;
    end
    
    //Загружаем схему системы
    SystemShema = xcosDiagramToScilab(SystemShemaName);
    
    //Векторизуемая функция вычислительного эксперимента
    function [result]=ComputerExperimentWithDataConvercion(ind)
        //Проводим вычислительный эксперимент
        systemOutputCharacteristics = ComputingExperiment(SystemParametrsNames,...//Имена параметров
                                                          SystemParametrsValues(ind,:),...//Значения параметров
                                                          SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                                          SystemShema...//Схема системы
                                                          );
                                                          
        //Приводим выходные характеристики системы к одному временному масштабу
        DynamicsInGeneralTimeGrid = DynamicsToGeneralTimeGrid(systemOutputCharacteristics,...//Массив динамик
                                                              SystemOutputCharacteristicsNamesIndexes,...//Индексы имен динамик
                                                              SystemOutputCharacteristicsIndexes,...//Индексы динамик (в именах)
                                                              TimeMoments...//Моменты времени
                                                              );
                                                              
        //Приводим параметры и формируем результат
        result = [ones(size(DynamicsInGeneralTimeGrid)(1), 1) * SystemParametrsValues(ind,:), DynamicsInGeneralTimeGrid];
    endfunction
    
    //Проводим вычислительные эксперименты и преобразовываем результаты этих экспериментов
    Results = Vectorization((1:size(SystemParametrsValues)(1))', ComputerExperimentWithDataConvercion);
    if isemptyModelParametrsNames then
        ModelParametrsValues = Results(:,1:size(SystemParametrsNames, '*'));
    else
        ModelParametrsValues = Results(:,Find(ModelParametrsNames, SystemParametrsNames));
    end
    SystemOutputCharacteristics = Results(:,(size(SystemParametrsValues)(2) + 1):size(Results)(2));
endfunction
