//Функция генерации обучающих данных (для динамики выходных характеристик)
function [SystemOutputCharacteristics,...//Выходные характеристики
          ModelParametrsValues...//Значения параметров модели
          ]=AdvancedModelLearningDataGeneralTimeGridWithGenericParametrs(GenericParametrsNames,...//Имена параметров, определяющих динамику
                                                                         GenericParametrsValues,...//Значения параметров, определяющих динамику
                                                                         systemAttributes...//Аттрибуты системы
                                                                         )
    //Проверяем аргументы
    if argn(2) ~= 3 then
        error('Function AdvancedModelLearningDataDynamicWithGenericParametrs takes 3 arguments');
        return;
    end
    
    //Проверяем корректность аргументов
    sizeGenericParametrsNames = size(GenericParametrsNames);
    if (type(GenericParametrsNames) ~= 10) || (sizeGenericParametrsNames(1) ~= 1) then
        error('The first argument of function AdvancedModelLearningDataGeneralTimeGridWithGenericParametrs is string matrix 1xM');
        return;
    end
    if isempty(GenericParametrsValues) ||...
       (type(GenericParametrsValues) ~= 1) then
        error('The second argument of function AdvancedModelLearningDataGeneralTimeGridWithGenericParametrs is real matrix NxM');
        return;
    end
    sizeGenericParametrsValues = size(GenericParametrsValues);
    if sizeGenericParametrsValues(2) ~= sizeGenericParametrsNames(2) then
        error('The first and second arguments of function AdvancedModelLearningDataGeneralTimeGridWithGenericParametrs are matrixes with same columns');
        return;
    end
    if (type(systemAttributes) ~= 17) ||...
       (typeof(systemAttributes) ~= 'SystemAttributesInGenericTimeGrid') then
        error('The third argument of function AdvancedModelLearningDataGeneralTimeGridWithGenericParametrs is system attribute type');
        return;
    end
    if sizeGenericParametrsValues(1) ~= size(systemAttributes.SystemParametrsValues)(1) then
        error('The second argument of function AdvancedModelLearningDataGeneralTimeGridWithGenericParametrs and individual system parametrs matrix are matrixes with same rows');
        return;
    end
    
    //Формируем входные данные
    SystemParametrsNames = [GenericParametrsNames, systemAttributes.SystemParametrsNames];//Имена параметров системы
    SystemParametrsValues = [GenericParametrsValues, systemAttributes.SystemParametrsValues];//Величины параметров системы
    
    //Проводим вычислительные эксперименты
    [SystemOutputCharacteristics,...//Выходные характеристики
     ModelParametrsValues...//Значения параметров модели
     ]=AdvancedModelLearningDataGeneralTimeGrid(systemAttributes.ModelParametrsNames,...//Имена параметров модели
                                                SystemParametrsNames,...//Имена параметров, определяющих динамику
                                                SystemParametrsValues,...//Значения параметров, определяющих динамику
                                                systemAttributes.SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                                systemAttributes.SystemOutputCharacteristicsNamesIndexes,...//Индексы выходных характеристик системы
                                                systemAttributes.SystemOutputCharacteristicsIndexes,...//Индексы выходных характеристик системы (в именах)
                                                systemAttributes.SystemShemaName,...//Имя схемы системы
                                                systemAttributes.TimeMoments...//Моменты времени
                                                );
endfunction
