function [parametrs...//Параметры
          ]=CountDynamicsProections(Dynamics,...//Массив динамик
                                    DynamicsNamesIndexes,...//Индексы имен динамик
                                    DynamicsIndexes,...//Индексы динамик (в именах)
                                    DynamicCompressionFunctions...//Функция фильтра динамики
                                    )
    //Проверяем число аргументов
    if argn(2) ~= 4 then
        error('Function CountDynamicsProections takes 4 arguments');
        return;
    end
    
    //Проверяем корректность аргументов
    if isempty(Dynamics) then
        parametrs = [];
        return;
    end
    if (type(Dynamics) ~= 17) || (typeof(Dynamics) ~= 'st') then
        error('The first argument of CountDynamicsProections function is dynamic variables type');
        return;
    end
    if isempty(DynamicsNamesIndexes) then
        parametrs = [];
        return;
    end
    if type(DynamicsNamesIndexes) ~= 1 then
        error('The second argument of CountDynamicsProections function is array of integer');
        return;
    end
    if size(DynamicsNamesIndexes)(1) ~= 1 then
        error('The dynamics names indexes matrix is 1xN vector');
        return;
    end
    if isempty(DynamicsIndexes) then
        parametrs = [];
        return;
    end
    if type(DynamicsIndexes) ~= 1 then
        error('The third argument of CountDynamicsProections function is array of integer');
        return;
    end
    if or(size(DynamicsNamesIndexes) ~= size(DynamicsIndexes)) then
        error('The sizes of dynamics names idexes and dynamic indexes matrixes must be equality');
        return;
    end
    if type(DynamicCompressionFunctions) ~= 17 then
        error('The 4th argument of CountDynamicsProections function is array of function');
        return;
    end
    if or(size(DynamicsNamesIndexes) ~= size(DynamicCompressionFunctions)) then
        error('The sizes of dynamics names idexes and compression function matrixes must be equality');
        return;
    end
    
    //Проверка корректности функций сжатия
    nDynamics = length(DynamicsIndexes);//Число сжимаемых динамик
    function [res]=ExecCorrectingCompressionFunction(ind)//Вспомогательная функция проверки корректности
        res = (type(DynamicCompressionFunctions{ind}) ~= 13);
    endfunction
    if or(Vectorization(1:nDynamics, ExecCorrectingCompressionFunction)) then
        error('The 4th argument of CountDynamicsProections function is array of function');
        return;
    end
    
    //Выполняем фильтрацию
    function [parametrs]=ExecCompression(ind)//Вспомогательная функция фильтрации по индексу
        parametrs=DynamicCompressionFunctions{ind}(Dynamics(DynamicsNamesIndexes(ind)).time,...
                                                   Dynamics(DynamicsNamesIndexes(ind)).values(:,DynamicsIndexes(ind)));
    endfunction
    parametrs=Vectorization(1:nDynamics, ExecCompression);//Фильтруем динамики и получаем ее параметры
endfunction
